﻿Imports System.Text
Imports System.Collections.ObjectModel
Imports System.Net

Namespace WpfApplication31
	''' <summary>
	''' Interaction logic for MainWindow.xaml
	''' </summary>
	Partial Public Class MainWindow
		Inherits Window
		Public Sub New()
			InitializeComponent()

			AddHandler Loaded, AddressOf MainWindow_Loaded
		End Sub

		Private Sub MainWindow_Loaded(ByVal sender As Object, ByVal e As RoutedEventArgs)
			TweetList.ItemsSource = _tweets
		End Sub

		Private _tweets As New ObservableCollection(Of Tweet)()

		Private Sub GetTweets_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
			Dim client As New WebClient()

            AddHandler client.DownloadStringCompleted, AddressOf OnDownloadStringCompleted

			client.DownloadStringAsync(New Uri("http://search.twitter.com/search.atom?q=wpf"))
		End Sub
		
        Private Sub OnDownloadStringCompleted(ByVal s As Object, ByVal ea As Object)
            Dim doc As XDocument = XDocument.Parse(ea.Result)
            Dim ns As XNamespace = "http://www.w3.org/2005/Atom"

            Dim items = From item In doc.Descendants(ns + "entry") _
                        Select New Tweet() With
                               {
                                   .Title = item.Element(ns + "title").Value,
                                   .Image = New Uri(( _
                                        From xe As XElement In item.Descendants(ns + "link") _
                                        Where xe.Attribute("type").Value = "image/png" _
                                        Select xe.Attribute("href").Value).First()),
                                   .Link = New Uri(( _
                                        From xe As XElement In item.Descendants(ns + "link") _
                                        Where xe.Attribute("type").Value = "text/html" _
                                        Select xe.Attribute("href").Value).First())
                                }

            For Each t As Tweet In items
                _tweets.Add(t)
            Next t

            UpdateOverlayIcon()
        End Sub

        Private Class Context
            Public Property CountText() As String
        End Class

		Private Sub UpdateOverlayIcon()
			Dim iconWidth As Integer = 20
			Dim iconHeight As Integer = 20

			Dim context As New Context()
			If _tweets.Count > 99 Then
				context.CountText = "+"
			Else
				context.CountText = _tweets.Count.ToString()
			End If


			Dim bmp As New RenderTargetBitmap(iconWidth, iconHeight, 96, 96, PixelFormats.Default)

			Dim root As New ContentControl()

			root.ContentTemplate = (CType(Resources("OverlayIcon"), DataTemplate))
			root.Content = context

			root.Arrange(New Rect(0, 0, iconWidth, iconHeight))

			bmp.Render(root)

			TaskbarItemInfo.Overlay = CType(bmp, ImageSource)
		End Sub

	End Class

End Namespace
